from django.contrib import admin

from smoothglue.core.admin import DataAdmin
from smoothglue.map.models import ImageryLayer


class ImageryLayerAdmin(DataAdmin):
    list_display = (
        "name",
        "provider_type",
        "is_active",
    )
    list_editable = ("is_active",)
    list_filter = ("provider_type",)


admin.site.register(ImageryLayer, ImageryLayerAdmin)
