# Generated by Django 4.2.13 on 2024-06-18 00:51

import uuid

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="ImageryLayer",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                        unique=True,
                    ),
                ),
                ("name", models.CharField(blank=True, max_length=64, unique=True)),
                ("url", models.CharField(blank=True, max_length=512)),
                (
                    "provider_type",
                    models.CharField(
                        choices=[
                            ("NO", "None"),
                            ("AG", "ArcGis Map Server"),
                            ("TL", "Tile Map Service"),
                            ("BG", "Bing Map Imagery"),
                            ("GG", "Google Earth Enterprise"),
                            ("OS", "Open Street Map"),
                            ("WM", "Web Map Tile Service"),
                            ("UT", "Url Template Imagery"),
                            ("GO", "Geo Server"),
                        ],
                        default="NO",
                        max_length=2,
                    ),
                ),
                ("sort_order", models.IntegerField(blank=True, null=True)),
                ("is_active", models.BooleanField(default=True)),
            ],
        ),
    ]
