# boot_django.py
#
# This file sets up and configures Django. It's used by scripts that need to
# execute as if running in a Django server.
import os

import django
from django.conf import settings

BASE_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "smoothglue/map"))


def boot_django():
    # The settings.configure() call takes a list of args that are equivalent to variables
    # defined in a settings.py file.
    # Anything you would need in your settings.py to make your app run gets passed here
    settings.configure(
        BASE_DIR=BASE_DIR,
        DEBUG=True,
        DATABASES={
            "default": {
                "ENGINE": "django.db.backends.sqlite3",
                "NAME": os.path.join(BASE_DIR, "db.sqlite3"),
            }
        },
        INSTALLED_APPS=[
            "django.contrib.contenttypes",
            "django.contrib.auth",
            "smoothglue.map",
        ],
        TIME_ZONE="UTC",
        USE_TZ=True,
    )
    django.setup()
