from django.urls import include, path
from rest_framework import routers

from smoothglue.map import views

ROUTER = routers.DefaultRouter()

ROUTER.register(
    r"imagelayersviews", views.ImageryLayerViewset, basename="imagelayersviews"
)


urlpatterns = [path("", include(ROUTER.urls))]
